@@ -28,11 +28,13 @@ import numpy as np
 from PIL import Image
 from PIL import ImageDraw
 
+from nucleus.io import gfile
 from nucleus.protos import variants_pb2
 
 DEEPVARIANT_CHANNEL_NAMES = [
     'read base', 'base quality', 'mapping quality', 'strand',
-    'read supports variant', 'base differs from ref'
+    'read supports variant', 'base differs from ref', 'alternate allele 1',
+    'alternate allele 2'
 ]
 
 
@@ -262,7 +264,10 @@ def save_to_png(arr,
 
   Args:
     arr: numpy array. Input array to save.
-    path: str. file path at which to save the image.
+    path: str. File path at which to save the image. A .png prefix is added if
+      the path does not already have one. Leave empty to save at /tmp/tmp.png,
+      which is useful when only temporarily showing the image in a Colab
+      notebook.
     image_mode: "RGB" or "L". Leave as default=None to choose based on image
       dimensions.
     show: bool. Whether to display the image using IPython (for notebooks).
@@ -296,7 +301,11 @@ def save_to_png(arr,
   # Saving to a temporary file is needed even when showing in a notebook
   if path is None:
     path = '/tmp/tmp.png'
-  img.save(path)
+  elif not path.endswith('.png'):
+    # Only PNG is supported because JPEG files are unnecessarily 3 times larger.
+    path = '{}.png'.format(path)
+  with gfile.Open(path, 'wb') as fout:
+    img.save(fout, format=path.split('.')[-1])
 
   # Show image (great for notebooks)
   if show:
@@ -348,6 +357,18 @@ def array_to_png(arr,
       scale=scale)
 
 
+def _deepvariant_channel_names(num_channels):
+  """Get DeepVariant channel names for the given number of channels."""
+  # Add additional empty labels if there are more channels than expected.
+  filler_labels = [
+      'channel {}'.format(i + 1)
+      for i in range(len(DEEPVARIANT_CHANNEL_NAMES), num_channels)
+  ]
+  labels = DEEPVARIANT_CHANNEL_NAMES + filler_labels
+  # Trim off any extra labels.
+  return labels[0:num_channels]
+
+
 def draw_deepvariant_pileup(example=None,
                             channels=None,
                             composite_type=None,
@@ -386,7 +407,7 @@ def draw_deepvariant_pileup(example=None,
   if composite_type is None:
     img_array = np.concatenate(channels, axis=1)
     if annotated and labels is None:
-      labels = DEEPVARIANT_CHANNEL_NAMES
+      labels = _deepvariant_channel_names(len(channels))
   elif composite_type == 'RGB':
     img_array = convert_6_channels_to_rgb(channels)
     if annotated and labels is None:
